@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -71,7 +71,6 @@ import org.scribe.model.Verb;
 import org.w3c.dom.Element;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
-import com.openexchange.java.StringAllocator;
 import com.openexchange.messaging.IndexRange;
 import com.openexchange.messaging.MessagingAccount;
 import com.openexchange.messaging.MessagingAddressHeader;
@@ -99,6 +98,7 @@ import com.openexchange.messaging.facebook.utility.FacebookMessagingUtility.FQLQ
 import com.openexchange.messaging.facebook.utility.FacebookMessagingUtility.FQLQueryType;
 import com.openexchange.messaging.facebook.utility.FacebookMessagingUtility.StaticFiller;
 import com.openexchange.messaging.facebook.utility.FacebookPage;
+import com.openexchange.messaging.facebook.utility.FacebookRequestTuner;
 import com.openexchange.messaging.facebook.utility.FacebookUser;
 import com.openexchange.messaging.generic.AttachmentFinderHandler;
 import com.openexchange.messaging.generic.MessageParser;
@@ -524,7 +524,7 @@ public final class FacebookMessagingMessageAccess extends AbstractFacebookAccess
                         Verb.POST,
                         "https://graph.facebook.com/" + facebookUserId + "/feed?message=" + encode(content.getData()));
                 facebookOAuthAccess.getFacebookOAuthService().signRequest(facebookOAuthAccess.getFacebookAccessToken(), request);
-                final Response response = request.send();
+                final Response response = request.send(FacebookRequestTuner.getInstance());
                 final JSONObject result = new JSONObject(response.getBody());
                 if (result.has("error")) {
                     final JSONObject error = result.getJSONObject("error");
@@ -1005,7 +1005,7 @@ public final class FacebookMessagingMessageAccess extends AbstractFacebookAccess
             return null;
         }
         final int length = chars.length();
-        final StringAllocator builder = new StringAllocator(length);
+        final StringBuilder builder = new StringBuilder(length);
         for (int i = 0; i < length; i++) {
             final char c = chars.charAt(i);
             builder.append((c >= 'A') && (c <= 'Z') ? (char) (c ^ 0x20) : c);
