@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -101,7 +101,7 @@ public final class CachingMessagingAccountStorage implements MessagingAccountSto
      * @return The new cache key
      */
     static CacheKey newCacheKey(final CacheService cacheService, final String serviceId, final int id, final int user, final int cid) {
-        return cacheService.newCacheKey(cid, serviceId, Integer.valueOf(id), Integer.valueOf(user));
+        return cacheService.newCacheKey(cid, serviceId, String.valueOf(id), String.valueOf(user));
     }
 
     private static void invalidateMessagingAccount(final String serviceId, final int id, final int user, final int cid) throws OXException {
@@ -228,7 +228,7 @@ public final class CachingMessagingAccountStorage implements MessagingAccountSto
     }
 
     public void removeUnrecoverableItems(MessagingService service, String secret, Session session) throws OXException {
-        delegatee.removeUnrecoverableItems(service, secret, session);        
+        delegatee.removeUnrecoverableItems(service, secret, session);
     }
 
 }
