@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,8 +50,10 @@
 package com.openexchange.twitter.osgi;
 
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.config.Reloadable;
 import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.twitter.TwitterService;
+import com.openexchange.twitter.internal.TwitterConfiguration;
 import com.openexchange.twitter.internal.TwitterServiceImpl;
 
 /**
@@ -82,6 +84,7 @@ public final class TwitterActivator extends HousekeepingActivator {
              * Register
              */
             registerService(TwitterService.class, new TwitterServiceImpl());
+            registerService(Reloadable.class, TwitterConfiguration.getInstance());
         } catch (final Exception e) {
             log.error("Failed start-up of bundle com.openexchange.twitter", e);
             throw e;
